==> polkit-kde-agent-1-5.8.7.tar.xz: polkit-kde-agent-1-5.8.7/polkit-kde-authentication-agent-1.desktop.cmake <==
[Desktop Entry]
Name=PolicyKit Authentication Agent
Name[ca]=Agent d'autenticació del PolicyKit
Name[ca@valencia]=Agent d'autenticació del PolicyKit
Name[cs]=Ověřovací agent PolicyKitu
Name[da]=PolicyKit autentificeringsagent
Name[de]=PolicyKit-Authentifizierungs-Agent
Name[el]=Πράκτορας ταυτοποίησης PolicyKit
Name[en_GB]=PolicyKit Authentication Agent
Name[es]=Agente de autenticación de PolicyKit
Name[et]=PolicyKiti autentimisagent
Name[fi]=PolicyKit-tunnistautumisagentti
Name[fr]=Agent d'authentification de « PolicyKit »
Name[gl]=Axente de autenticación de PolicyKit
Name[it]=Agente di autenticazione di PolicyKit
Name[ko]=PolicyKit 인증 에이전트
Name[nl]=Authenticatieagent van PolicyKit
Name[nn]=PolicyKit-autentiseringsagent
Name[pa]=ਪਾਲਸੀਕਿਟ ਪਰਮਾਣਕਿਤਾ ਏਜੰਟ
Name[pl]=Usługa uwierzytelnienia PolicyKit
Name[pt]=Agente de Autenticação do PolicyKit
Name[pt_BR]=Agente de Autenticação do PolicyKit
Name[ru]=Агент аутентификации PolicyKit
Name[sk]=Overovací dialóg PolicyKit
Name[sl]=Overitveni posrednik PolicyKit
Name[sr]=Полисикитов агент за аутентификовање
Name[sr@ijekavian]=Полисикитов агент за аутентификовање
Name[sr@ijekavianlatin]=PolicyKitov agent za autentifikovanje
Name[sr@latin]=PolicyKitov agent za autentifikovanje
Name[sv]=Policykit behörighetsmodul
Name[uk]=Агент розпізнавання PolicyKit
Name[x-test]=xxPolicyKit Authentication Agentxx
Name[zh_CN]=PolicyKit 认证代理
Name[zh_TW]=PolicyKit 認證代理程式
Comment=PolicyKit Authentication Agent
Comment[ca]=Agent d'autenticació del PolicyKit
Comment[ca@valencia]=Agent d'autenticació del PolicyKit
Comment[cs]=Ověřovací agent PolicyKitu
Comment[da]=PolicyKit autentificeringsagent
Comment[de]=PolicyKit-Authentifizierungs-Agent
Comment[el]=Πράκτορας ταυτοποίησης PolicyKit
Comment[en_GB]=PolicyKit Authentication Agent
Comment[es]=Agente de autenticación de PolicyKit
Comment[et]=PolicyKiti autentimisagent
Comment[fi]=PolicyKit-tunnistautumisagentti
Comment[fr]=Agent d'authentification de « PolicyKit »
Comment[gl]=Axente de autenticación de PolicyKit
Comment[it]=Agente di autenticazione di PolicyKit
Comment[ko]=PolicyKit 인증 에이전트
Comment[nl]=Authenticatieagent van PolicyKit
Comment[nn]=PolicyKit-autentiseringsagent
Comment[pa]=ਪਾਲਸੀਕਿਟ ਪਰਮਾਣਕਿਤਾ ਏਜੰਟ
Comment[pl]=Usługa uwierzytelnienia PolicyKit
Comment[pt]=Agente de Autenticação do PolicyKit
Comment[pt_BR]=Agente de Autenticação do PolicyKit
Comment[ru]=Агент аутентификации PolicyKit
Comment[sk]=Overovací dialóg PolicyKit
Comment[sl]=Overitveni posrednik PolicyKit
Comment[sr]=Полисикитов агент за аутентификовање
Comment[sr@ijekavian]=Полисикитов агент за аутентификовање
Comment[sr@ijekavianlatin]=PolicyKitov agent za autentifikovanje
Comment[sr@latin]=PolicyKitov agent za autentifikovanje
Comment[sv]=Policykit behörighetsmodul
Comment[uk]=Агент розпізнавання PolicyKit
Comment[x-test]=xxPolicyKit Authentication Agentxx
Comment[zh_CN]=PolicyKit 认证代理
Comment[zh_TW]=PolicyKit 認證代理程式
Exec=${CMAKE_INSTALL_FULL_LIBEXECDIR}/polkit-kde-authentication-agent-1
Terminal=false
Type=Application
Categories=
OnlyShowIn=KDE;
X-KDE-StartupNotify=false
X-KDE-autostart-phase=0
NoDisplay=true
X-DBUS-StartupType=Unique

==> polkit-kde-agent-1-5.8.9.tar.xz: polkit-kde-agent-1-5.8.9/polkit-kde-authentication-agent-1.desktop.cmake <==
[Desktop Entry]
Name=PolicyKit Authentication Agent
Name[ca]=Agent d'autenticació del PolicyKit
Name[ca@valencia]=Agent d'autenticació del PolicyKit
Name[cs]=Ověřovací agent PolicyKitu
Name[da]=PolicyKit autentificeringsagent
Name[de]=PolicyKit-Authentifizierungs-Agent
Name[el]=Πράκτορας ταυτοποίησης PolicyKit
Name[en_GB]=PolicyKit Authentication Agent
Name[es]=Agente de autenticación de PolicyKit
Name[et]=PolicyKiti autentimisagent
Name[eu]=PolicyKit autentifikazio agentea
Name[fi]=PolicyKit-tunnistautumisagentti
Name[fr]=Agent d'authentification de « PolicyKit »
Name[gl]=Axente de autenticación de PolicyKit
Name[id]=PolicyKit Authentication Agent
Name[it]=Agente di autenticazione di PolicyKit
Name[ko]=PolicyKit 인증 에이전트
Name[nl]=Authenticatieagent van PolicyKit
Name[nn]=PolicyKit-autentiseringsagent
Name[pa]=ਪਾਲਸੀਕਿਟ ਪਰਮਾਣਕਿਤਾ ਏਜੰਟ
Name[pl]=Usługa uwierzytelnienia PolicyKit
Name[pt]=Agente de Autenticação do PolicyKit
Name[pt_BR]=Agente de Autenticação do PolicyKit
Name[ru]=Агент аутентификации PolicyKit
Name[sk]=Overovací dialóg PolicyKit
Name[sl]=Overitveni posrednik PolicyKit
Name[sr]=Полисикитов агент за аутентификовање
Name[sr@ijekavian]=Полисикитов агент за аутентификовање
Name[sr@ijekavianlatin]=PolicyKitov agent za autentifikovanje
Name[sr@latin]=PolicyKitov agent za autentifikovanje
Name[sv]=Policykit behörighetsmodul
Name[uk]=Агент розпізнавання PolicyKit
Name[x-test]=xxPolicyKit Authentication Agentxx
Name[zh_CN]=PolicyKit 认证代理
Name[zh_TW]=PolicyKit 認證代理程式
Comment=PolicyKit Authentication Agent
Comment[ca]=Agent d'autenticació del PolicyKit
Comment[ca@valencia]=Agent d'autenticació del PolicyKit
Comment[cs]=Ověřovací agent PolicyKitu
Comment[da]=PolicyKit autentificeringsagent
Comment[de]=PolicyKit-Authentifizierungs-Agent
Comment[el]=Πράκτορας ταυτοποίησης PolicyKit
Comment[en_GB]=PolicyKit Authentication Agent
Comment[es]=Agente de autenticación de PolicyKit
Comment[et]=PolicyKiti autentimisagent
Comment[eu]=PolicyKit autentifikazio agentea
Comment[fi]=PolicyKit-tunnistautumisagentti
Comment[fr]=Agent d'authentification de « PolicyKit »
Comment[gl]=Axente de autenticación de PolicyKit
Comment[id]=Agen Kewenangan PolicyKit
Comment[it]=Agente di autenticazione di PolicyKit
Comment[ko]=PolicyKit 인증 에이전트
Comment[nl]=Authenticatieagent van PolicyKit
Comment[nn]=PolicyKit-autentiseringsagent
Comment[pa]=ਪਾਲਸੀਕਿਟ ਪਰਮਾਣਕਿਤਾ ਏਜੰਟ
Comment[pl]=Usługa uwierzytelnienia PolicyKit
Comment[pt]=Agente de Autenticação do PolicyKit
Comment[pt_BR]=Agente de Autenticação do PolicyKit
Comment[ru]=Агент аутентификации PolicyKit
Comment[sk]=Overovací dialóg PolicyKit
Comment[sl]=Overitveni posrednik PolicyKit
Comment[sr]=Полисикитов агент за аутентификовање
Comment[sr@ijekavian]=Полисикитов агент за аутентификовање
Comment[sr@ijekavianlatin]=PolicyKitov agent za autentifikovanje
Comment[sr@latin]=PolicyKitov agent za autentifikovanje
Comment[sv]=Policykit behörighetsmodul
Comment[uk]=Агент розпізнавання PolicyKit
Comment[x-test]=xxPolicyKit Authentication Agentxx
Comment[zh_CN]=PolicyKit 认证代理
Comment[zh_TW]=PolicyKit 認證代理程式
Exec=${CMAKE_INSTALL_FULL_LIBEXECDIR}/polkit-kde-authentication-agent-1
Terminal=false
Type=Application
Categories=
OnlyShowIn=KDE;
X-KDE-StartupNotify=false
X-KDE-autostart-phase=0
NoDisplay=true
X-DBUS-StartupType=Unique
